@@ -191,7 +191,7 @@ use Scalar::Util 'refaddr';
 use base 'Exporter';
 use v5.14;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 our @EXPORT = qw{
     one_row
@@ -1208,7 +1208,7 @@ sub setup_row {
                 }
                 my $sth = $_->foreign_key_info(undef, undef, undef, undef, undef, $table);
                 if ($sth) {
-                    @fkeys = grep {($_->{PKTABLE_NAME} || $_->{UK_TABLE_NAME}) && $_->{FK_COLUMN_NAME} !~ /[^a-z_0-9]/}
+                    @fkeys = grep {($_->{PKTABLE_NAME} || $_->{UK_TABLE_NAME}) && $_->{FK_COLUMN_NAME} !~ /[^a-z_0-9]/i}
                         map {
                         $_->{FK_COLUMN_NAME} = $_->{FKCOLUMN_NAME}
                             if $_->{FKCOLUMN_NAME};
@@ -1218,7 +1218,7 @@ sub setup_row {
                 }
                 $sth = $_->foreign_key_info(undef, undef, $table, undef, undef, undef);
                 if ($sth) {
-                    @refkeys = grep {($_->{PKTABLE_NAME} || $_->{UK_TABLE_NAME}) && $_->{FK_COLUMN_NAME} !~ /[^a-z_0-9]/}
+                    @refkeys = grep {($_->{PKTABLE_NAME} || $_->{UK_TABLE_NAME}) && $_->{FK_COLUMN_NAME} !~ /[^a-z_0-9]/i}
                         map {
                         $_->{FK_COLUMN_NAME} = $_->{FKCOLUMN_NAME}
                             if $_->{FKCOLUMN_NAME};
